
%% ABOUT THIS FILE
% ----------------------------------------------------------------------
% PARAMETER LISTS
% This code describes parameters about suspension system to be
% modeled. The code is called from a model construction code.
% ----------------------------------------------------------------------
% Type-B payload prototype for KAGRA
% Coded by T. Sekiguchi on 2015/04/10
% ----------------------------------------------------------------------


%% PHYSICAL CONSTANTS

g = 9.81; % Gravity constant



%% MATERIALS

% Maraging steel [Marval 18] 
E_maraging =  184e9;  % Young's modulus [N/m^2] (by E. Hennes)
P_maraging =   0.32;  % Poisson ratio (by E. Hennes)
G_maraging = E_maraging/P_maraging; % Shear modulus [N/m^2]
d_maraging =  8.0e3;  % Volume density [kg/m^3]
T_maraging =  2.0e9;  % Tensile strength [N/m^2]

% Piano wire (typical)
E_piano =  200e9;  % Young's modulus [N/m^2]
P_piano =   0.28;  % Poisson ratio
G_piano = E_piano/P_piano; % Shear modulus [N/m^2]
d_piano =  7.8e3;  % Volume density [kg/m^3]
T_piano =  2.0e9;  % Tensile strength [N/m^2]

% Tungsten (typical)
E_tungsten =  411e9;  % Young's modulus [N/m^2]
P_tungsten =   0.28;  % Poisson ratio
G_tungsten = E_tungsten/P_tungsten; % Shear modulus [N/m^2]
d_tungsten = 19.3e3;  % Volume density [kg/m^3]
T_tungsten =  2.0e9;  % Tensile strength [N/m^2] (*depends on diameter)



%% GROUND

groundname = {'GND'}; % Names of grounds inducing seismic excitation



%% RIGID-BODY

rigidbodyname = {'IR','IM','RM','TM'};
% Names of rigid bodies in the modeled suspension system

%  IR = intermediate recoil mass
%  IM = intermediate mass
%  RM = recoil mass
%  TM = test mass



%% RIGID-BODY PARAMETERS

% Mass of rigid bodies [kg]
mIR =  8.4;
mIM = 26.0;
mRM = 13.4;
mTM = 10.7;



% Moment of inertia [kg*m^2]
% around L(longitudinal), T(transversal) and V(vertical) axes
% corresponding to R(roll), P(pitch) and Y(yaw) motions

moiIR = [
    0.170   0       0       ;
    0       0.159   0       ;
    0       0       0.263   ;
    ];

moiIM = [
    0.187   0       0       ;
    0       0.145   0       ;
    0       0       0.247   ;
    ];

moiRM = [
    0.234   0       0       ;
    0       0.190   0       ;
    0       0       0.172   ;
    ];

moiTM = [
    0.083   0       0       ;
    0       0.051   0       ;
    0       0       0.051   ;
    ];



%% SUSPENSION WIRES, SPRINGS

% Wires from GND to IR
 n_wGND2IR =        3;  % Number of wires
 
 l_wGND2IR =   355e-3;  % Wire length [m]
 d_wGND2IR =     2e-3;  % Wire diameter [m]
 m_wGND2IR =      mIR;  % Total load on wires [kg]

 E_wGND2IR = E_maraging; % Young's modulus [N/m^2]
 G_wGND2IR = G_maraging; % Shear modulus [N/m^2]
 T_wGND2IR = T_maraging; % Tensile strength [N/m^2]

Qp_wGND2IR =      1e3;  % Q of pendulum mode
Qs_wGND2IR =      1e3;  % Q of stretch mode
Qb_wGND2IR =      1e3;  % Q of bending mode
Qt_wGND2IR =      1e3;  % Q of torsion mode

h1_wGND2IR = -79.7e-3;  % Vertical position of upper SP from upper body CoM [m]
h2_wGND2IR = +60.5e-3;  % Vertical position of lower SP from lower body CoM [m]
r1_wGND2IR =   158e-3;  % Horizontal distance btw upper SP and upper body CoM [m]
r2_wGND2IR =   158e-3;  % Horizontal distance btw lower SP and lower body CoM [m]



% Wires from GND to IM
 n_wGND2IM =        1;  % Number of wires

 l_wGND2IM =   585e-3;  % Wire length [m]
ln_wGND2IM =    26e-3;  % Wire neck length [m]
 d_wGND2IM =   2.5e-3;  % Wire diameter [m]
dn_wGND2IM =   2.0e-3;  % Wire neck diameter [m]
 m_wGND2IM = mIM+mRM+mTM;  % Total load on wires [kg]

 E_wGND2IM = E_maraging; % Young's modulus [N/m^2]
 G_wGND2IM = G_maraging; % Shear modulus [N/m^2]
 T_wGND2IM = T_maraging; % Tensile strength [N/m^2]
 
Qp_wGND2IM =      1e3;  % Q of pendulum mode
Qs_wGND2IM =      1e3;  % Q of stretch mode
Qb_wGND2IM =      1e3;  % Q of bending mode
Qt_wGND2IM =      1e3;  % Q of torsion mode
 
h1_wGND2IM =    -5e-3;  % Vertical position of upper SP from upper body CoM
h2_wGND2IM =   -19e-3;  % Vertical position of lower SP from lower body CoM

fsp_wGND2IM =    0.44;  % Resonant frequency of vertical spring
Bsp_wGND2IM =    1e-3;  % Isolation saturation level due to CoP
Qsp_wGND2IM =     5e1;  % Q of spring


% Wires from IM to RM
 n_wIM2RM  =        4;  % Number of wires

 l_wIM2RM  =   587e-3;  % Wire length [m]
 d_wIM2RM  =   0.6e-3;  % Wire diameter [m]
 m_wIM2RM  =      mRM;  % Total load on wires [kg]

 E_wIM2RM  = E_tungsten; % Young's modulus [N/m^2]
 G_wIM2RM  = G_tungsten; % Shear modulus [N/m^2]
 T_wIM2RM  = T_tungsten; % Tensile strength [N/m^2]
 
Qp_wIM2RM  =      1e3;  % Q of pendulum mode
Qs_wIM2RM  =      1e3;  % Q of stretch mode
Qb_wIM2RM  =      1e3;  % Q of bending mode
Qt_wIM2RM  =      1e3;  % Q of torsion mode

h1_wIM2RM  =     0e-3;  % Vertical position of upper SP from upper body CoM
h2_wIM2RM  =     0e-3;  % Vertical position of lower SP from lower body CoM
w1_wIM2RM  =   290e-3;  % Transversal sepration of wires in upper SP
w2_wIM2RM  =   290e-3;  % Transversal sepration of wires in upper SP
d1_wIM2RM  =    20e-3;  % Longitudinal separation of wires in upper SP
d2_wIM2RM  =    20e-3;  % Longitudinal separation of wires in upper SP


% Wires from IM to TM
 n_wIM2TM  =        4;  % Number of wires

 l_wIM2TM  =   587e-3;  % Wire length [m]
 d_wIM2TM  =   0.2e-3;  % Wire diameter [m]
 m_wIM2TM  =      mTM;  % Total load on wires [kg]

 E_wIM2TM  =  E_piano; % Young's modulus [N/m^2]
 G_wIM2TM  =  G_piano; % Shear modulus [N/m^2]
 T_wIM2TM  =  T_piano; % Tensile strength [N/m^2]
 
Qp_wIM2TM  =      1e4;  % Q of pendulum mode
Qs_wIM2TM  =      1e4;  % Q of stretch mode
Qb_wIM2TM  =      1e3;  % Q of bending mode
Qt_wIM2TM  =      1e3;  % Q of torsion mode

h1_wIM2TM  =     0e-3;  % Vertical position of upper SP from upper body CoM
h2_wIM2TM  =     0e-3;  % Vertical position of lower SP from lower body CoM
w1_wIM2TM  =   250e-3;  % Transversal sepration of wires in upper SP
w2_wIM2TM  =   250e-3;  % Transversal sepration of wires in upper SP
d1_wIM2TM  =    10e-3;  % Longitudinal separation of wires in upper SP
d2_wIM2TM  =    10e-3;  % Longitudinal separation of wires in upper SP



