
%% ABOUT THIS FILE
% ----------------------------------------------------------------------
% PARAMETER LISTS
% This code describes parameters about suspension system to be
% modeled. The code is called from a model construction code.
% ----------------------------------------------------------------------
% Type-B1 prototype for KAGRA
% Coded by T. Sekiguchi on 2015/05/04
% ----------------------------------------------------------------------


%% PHYSICAL CONSTANTS

g = 9.81; % Gravity constant



%% MATERIALS

% Maraging steel [Marval 18] 
E_maraging =  184e9;  % Young's modulus [N/m^2] (by E. Hennes)
P_maraging =   0.32;  % Poisson ratio (by E. Hennes)
G_maraging =  E_maraging/2/(1+P_maraging); % Shear modulus [N/m^2]
d_maraging =  8.0e3;  % Volume density [kg/m^3]
T_maraging =  2.0e9;  % Tensile strength [N/m^2]
Q_maraging =  1.0e4;  % Quality factor

% Piano wire (typical)
E_piano =  200e9;  % Young's modulus [N/m^2]
P_piano =   0.28;  % Poisson ratio
G_piano =  E_piano/2/(1+P_piano); % Shear modulus [N/m^2]
d_piano =  7.8e3;  % Volume density [kg/m^3]
T_piano =  2.0e9;  % Tensile strength [N/m^2]
Q_piano =  1.0e4;  % Quality factor

% Tungsten (typical)
E_tungsten =  411e9;  % Young's modulus [N/m^2]
P_tungsten =   0.28;  % Poisson ratio
G_tungsten =  E_tungsten/2/(1+P_tungsten); % Shear modulus [N/m^2]
d_tungsten = 19.3e3;  % Volume density [kg/m^3]
T_tungsten =  2.0e9;  % Tensile strength [N/m^2] (*depends on diameter)
Q_tungsten =  1.0e4;  % Quality factor


%% GROUND

groundname = {'GND'}; % Names of grounds inducing seismic excitation



%% RIGID-BODY

rigidbodyname = {'F0','MD','F1','BF','IR','IM','RM','TM'};
% Names of rigid bodies in the modeled suspension system

%  F0 = filter 0 (top filter)
%  MD = magnetic damper
%  F1 = filter 1 (standard filter)
%  F2 = filter 2 (bottom filter)
%  IR = intermediate recoil mass
%  IM = intermediate mass
%  RM = recoil mass
%  TM = test mass



%% RIGID-BODY PARAMETERS

% Mass of rigid bodies [kg]
mF0 = 554.0;
mMD =  18.0;
mF1 = 112.7;
mF2 = 106.9;
mIR =   8.3;
mIM =  26.1;
mRM =  13.2;
mTM =  10.7;



% Moment of inertia [kg*m^2]
% around L(longitudinal), T(transversal) and V(vertical) axes
% corresponding to R(roll), P(pitch) and Y(yaw) motions


moiF0 = [
    97.5    0       0       ;
    0       97.5    0       ;
    0       0       191.4   ;
    ];

moiMD = [
    0.717   0       0       ;
    0       0.717   0       ;
    0       0       1.493   ;
    ];

moiF1 = [
    4.68    0.61    0       ;
    0.61    4.55    0       ;
    0       0       7.87    ;
    ];

moiF2 = [
    4.10    0       0       ;
    0       4.01    0       ;
    0       0       6.75    ;
    ];

moiIR = [
    0.170   0       0       ;
    0       0.159   0       ;
    0       0       0.263   ;
    ];

moiIM = [
    0.187   0       0       ;
    0       0.145   0       ;
    0       0       0.247   ;
    ];

moiRM = [
    0.234   0       0       ;
    0       0.190   0       ;
    0       0       0.172   ;
    ];

moiTM = [
    0.083   0       0       ;
    0       0.051   0       ;
    0       0       0.051   ;
    ];

% Rotation of RM
% rotang = 50e-3;  % 50 [mrad] (2.9 [deg])
% rotPRM = [
%      cos(rotang)  0  sin(rotang);
%           0       1      0     ;
%     -sin(rotang)  0  cos(rotang);
%     ];
% moiRM = rotPRM'*moiRM*rotPRM;

%% INVERTED PENDULUM

% IP from GND to F0
  f_ipGND2F0 = 80e-3;   % Resonant frequency [Hz]
  m_ipGND2F0 = mF0+mMD+mF1+mF2+mIR+mIM+mRM+mTM; % Total load [kg]
  l_ipGND2F0 = 480e-3;  % Length of legs [m]
  r_ipGND2F0 = 610e-3;  % Distance between leg and center [m]
  B_ipGND2F0 = 1e-4;    % Saturation level due to CoP
  Q_ipGND2F0 = 3e3;     % Quality factor
 kt_ipGND2F0 = 35;      % Additional torsion stiffness [Nm/rad]



%% DAMPER

% Damper between MD and F1
  pos_dampMD = [0  0  -10e-3];  % damping point on MD
  pos_dampF1 = [0  0 +180e-3];  % damping point on F1
  mat_dampMDF1 = diag([50,50,125,2.5,2.5,2]); % damping coefficient matrix




%% SUSPENSION WIRES, SPRINGS

% Wires from F0 to MD
 n_wF02MD =        3;  % Number of wires
 
 l_wF02MD =   955e-3;  % Wire length [m]
 d_wF02MD =     2e-3;  % Wire diameter [m]
 m_wF02MD =      mMD;  % Total load on wires [kg]

 E_wF02MD = E_maraging; % Young's modulus [N/m^2]
 G_wF02MD = G_maraging; % Shear modulus [N/m^2]
 T_wF02MD = T_maraging; % Tensile strength [N/m^2]
 Q_wF02MD = Q_maraging; % Quality factor

h1_wF02MD =   -80e-3;  % Vertical position of upper SP from upper body CoM [m]
h2_wF02MD =   +17e-3;  % Vertical position of lower SP from lower body CoM [m]
r1_wF02MD =   290e-3;  % Horizontal distance btw upper SP and upper body CoM [m]
r2_wF02MD =   290e-3;  % Horizontal distance btw lower SP and lower body CoM [m]



% Wires from F0 to F1
 n_wF02F1 =        1;  % Number of wires

 l_wF02F1 =  1280e-3;  % Wire length [m]
ln_wF02F1 =  26.5e-3;  % Wire neck length [m]
 d_wF02F1 =   4.5e-3;  % Wire diameter [m]
dn_wF02F1 =   3.0e-3;  % Wire neck diameter [m]
 m_wF02F1 = mF1+mF2+mIM+mIR+mRM+mTM;  % Total load on wires [kg]

 E_wF02F1 = E_maraging; % Young's modulus [N/m^2]
 G_wF02F1 = G_maraging; % Shear modulus [N/m^2]
 T_wF02F1 = T_maraging; % Tensile strength [N/m^2]
 Q_wF02F1 = Q_maraging; % Quality factor

h1_wF02F1 =   120e-3;  % Vertical position of upper SP from upper body CoM
h2_wF02F1 =   -15e-3;  % Vertical position of lower SP from lower body CoM

fsp_wF02F1 =    0.33;  % Resonant frequency of vertical spring
Bsp_wF02F1 =    1e-3;  % Isolation saturation level due to CoP
Qsp_wF02F1 =     5e1;  % Q of spring


% Wires from F1 to F2
 n_wF12F2 =        1;  % Number of wires

 l_wF12F2 = 513.4e-3;  % Wire length [m]
ln_wF12F2 =  26.5e-3;  % Wire neck length [m]
 d_wF12F2 =   4.5e-3;  % Wire diameter [m]
dn_wF12F2 =   2.5e-3;  % Wire neck diameter [m]
 m_wF12F2 = mF2+mIR+mIM+mRM+mTM;  % Total load on wires [kg]

 E_wF12F2 = E_maraging; % Young's modulus [N/m^2]
 G_wF12F2 = G_maraging; % Shear modulus [N/m^2]
 T_wF12F2 = T_maraging; % Tensile strength [N/m^2]
 Q_wF12F2 = Q_maraging; % Quality factor

h1_wF12F2 =   -30e-3;  % Vertical position of upper SP from upper body CoM
h2_wF12F2 =    10e-3;  % Vertical position of lower SP from lower body CoM

fsp_wF12F2 =    0.38;  % Resonant frequency of vertical spring [Hz]
Bsp_wF12F2 =    1e-3;  % Isolation saturation level due to CoP
Qsp_wF12F2 =     3e1;  % Q of spring



% Wires from F2 to IR
 n_wF22IR =        3;  % Number of wires
 
 l_wF22IR =   355e-3;  % Wire length [m]
 d_wF22IR =     2e-3;  % Wire diameter [m]
 m_wF22IR =      mIR;  % Total load on wires [kg]

 E_wF22IR = E_maraging; % Young's modulus [N/m^2]
 G_wF22IR = G_maraging; % Shear modulus [N/m^2]
 T_wF22IR = T_maraging; % Tensile strength [N/m^2]
 Q_wF22IR = Q_maraging; % Quality factor

h1_wF22IR = -79.7e-3;  % Vertical position of upper SP from upper body CoM [m]
h2_wF22IR = +60.5e-3;  % Vertical position of lower SP from lower body CoM [m]
r1_wF22IR =   158e-3;  % Horizontal distance btw upper SP and upper body CoM [m]
r2_wF22IR =   158e-3;  % Horizontal distance btw lower SP and lower body CoM [m]



% Wires from F2 to IM
 n_wF22IM =        1;  % Number of wires

 l_wF22IM =   585e-3;  % Wire length [m]
ln_wF22IM =  26.5e-3;  % Wire neck length [m]
 d_wF22IM =   2.5e-3;  % Wire diameter [m]
dn_wF22IM =   2.0e-3;  % Wire neck diameter [m]
 m_wF22IM = mIM+mRM+mTM;  % Total load on wires [kg]

 E_wF22IM = E_maraging; % Young's modulus [N/m^2]
 G_wF22IM = G_maraging; % Shear modulus [N/m^2]
 T_wF22IM = T_maraging; % Tensile strength [N/m^2]
 Q_wF22IM = Q_maraging; % Quality factor
 
h1_wF22IM =    -5e-3;  % Vertical position of upper SP from upper body CoM
h2_wF22IM = -18.5e-3;  % Vertical position of lower SP from lower body CoM

fsp_wF22IM =    0.44;  % Resonant frequency of vertical spring
Bsp_wF22IM =    1e-3;  % Isolation saturation level due to CoP
Qsp_wF22IM =     5e1;  % Q of spring


% Wires from IM to RM
 n_wIM2RM  =        4;  % Number of wires

 l_wIM2RM  =   587e-3;  % Wire length [m]
 d_wIM2RM  =   0.6e-3;  % Wire diameter [m]
 m_wIM2RM  =      mRM;  % Total load on wires [kg]

 E_wIM2RM  = E_tungsten; % Young's modulus [N/m^2]
 G_wIM2RM  = G_tungsten; % Shear modulus [N/m^2]
 T_wIM2RM  = T_tungsten; % Tensile strength [N/m^2]
 Q_wIM2RM  = Q_tungsten; % Quality factor

h1_wIM2RM  =     0e-3;  % Vertical position of upper SP from upper body CoM
h2_wIM2RM  =     0e-3;  % Vertical position of lower SP from lower body CoM
w1_wIM2RM  =   145e-3;  % Transversal sepration of wires in upper SP
w2_wIM2RM  =   145e-3;  % Transversal sepration of wires in upper SP
d1_wIM2RM  =    10e-3;  % Longitudinal separation of wires in upper SP
d2_wIM2RM  =    10e-3;  % Longitudinal separation of wires in upper SP


% Wires from IM to TM
 n_wIM2TM  =        4;  % Number of wires

 l_wIM2TM  =   587e-3;  % Wire length [m]
 d_wIM2TM  =   0.2e-3;  % Wire diameter [m]
 m_wIM2TM  =      mTM;  % Total load on wires [kg]

 E_wIM2TM  =  E_piano; % Young's modulus [N/m^2]
 G_wIM2TM  =  G_piano; % Shear modulus [N/m^2]
 T_wIM2TM  =  T_piano; % Tensile strength [N/m^2]
 Q_wIM2TM  =  Q_piano; % Quality factor

h1_wIM2TM  =     0e-3;  % Vertical position of upper SP from upper body CoM
h2_wIM2TM  =     0e-3;  % Vertical position of lower SP from lower body CoM
w1_wIM2TM  =   125e-3;  % Transversal sepration of wires in upper SP
w2_wIM2TM  =   125e-3;  % Transversal sepration of wires in lower SP
d1_wIM2TM  =     5e-3;  % Longitudinal separation of wires in upper SP
d2_wIM2TM  =     5e-3;  % Longitudinal separation of wires in lower SP



